@@ -19,7 +19,7 @@
 
 //=== Database (abstract base class) =======================================
 //
-// This is the base class for all database classes.
+// This is the common interface of database classes used in pdx.
 //
 class Database {
 
@@ -27,6 +27,7 @@ class Database {
 
 	virtual	~Database ();
 
+	virtual void Connect () throw (Xception) =0;
 	virtual void Select (shared_ptr<Selection>& selection, const string& collection, const ptime& begin, const ptime& end) const throw (Xception) =0;
 	virtual string GetVersion () const throw (Xception) =0;
 };
